package com.ruoyi.report.mapper;

import java.util.List;
import com.ruoyi.report.domain.RecordDeviceamountDay;

/**
 * 设备产量日报Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-11-03
 */
public interface RecordDeviceamountDayMapper 
{
    /**
     * 查询设备产量日报
     * 
     * @param objid 设备产量日报ID
     * @return 设备产量日报
     */
    public RecordDeviceamountDay selectRecordDeviceamountDayById(Long objid);

    /**
     * 查询设备产量日报列表
     * 
     * @param recordDeviceamountDay 设备产量日报
     * @return 设备产量日报集合
     */
    public List<RecordDeviceamountDay> selectRecordDeviceamountDayList(RecordDeviceamountDay recordDeviceamountDay);

    /**
     * 新增设备产量日报
     * 
     * @param recordDeviceamountDay 设备产量日报
     * @return 结果
     */
    public int insertRecordDeviceamountDay(RecordDeviceamountDay recordDeviceamountDay);

    /**
     * 修改设备产量日报
     * 
     * @param recordDeviceamountDay 设备产量日报
     * @return 结果
     */
    public int updateRecordDeviceamountDay(RecordDeviceamountDay recordDeviceamountDay);

    /**
     * 删除设备产量日报
     * 
     * @param objid 设备产量日报ID
     * @return 结果
     */
    public int deleteRecordDeviceamountDayById(Long objid);

    /**
     * 批量删除设备产量日报
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteRecordDeviceamountDayByIds(String[] objids);
}
